<script setup>
import AdminAuthenticatedLayout from '@/Layouts/AdminAuthenticatedLayout.vue';
import InputError from '@/Components/InputError.vue';
import InputLabel from '@/Components/InputLabel.vue';
import PrimaryButton from '@/Components/PrimaryButton.vue';
import TextInput from '@/Components/TextInput.vue';
import { ref, computed } from 'vue';
import { Head, useForm, usePage } from '@inertiajs/vue3';

const page = usePage();
const form = useForm({
    name: '',
    make: [],
    model: [],
    year: [],
});
const carMakes = computed(() => page.props.carMakes || []);
const carModels = computed(() => page.props.carModels || []);
const flashMessage = ref('');

const years = generateYears(1949, new Date().getFullYear());
const selectedYear = new Date().getFullYear();

function generateYears(start, end) {
  const years = [];
  for (let year = start; year <= end; year++) {
    years.push(year);
  }
  return years;
}

const reversedYears = computed(() => [...years].reverse());

const submit = () => {
    form.post(route('admin.products.createbodystyle'), {
        onSuccess: () => {
            form.reset()
            flashMessage.value = "Car Body Style added successfully!";
        },
        onError: (error) => {
            console.error(error);
        }
    });
};
</script>

<template>

    <Head title="Add Body Style" />

    <AdminAuthenticatedLayout>

        <template #header>
            <h2 class="font-semibold text-xl text-gray-800 leading-tight">Add Body Style</h2>
        </template>

        <div class="py-12 container">

            <div v-if="flashMessage" class="mx-auto sm:px-6 lg:px-8 font-bold text-green-600">
                <div class="form-row px-8">
                    <div class="col-md-6">
                        <h4>{{ flashMessage }}</h4>
                    </div>
                </div>
            </div>

            <div class="content-box sm:rounded-lg">
                <form @submit.prevent="submit">
                    <div class="form-row">

                        <div class="mt-4 col-md-3">
                            <InputLabel for="year" value="Year" />

                            <select class="w-full mt-1 block border-gray-300 rounded-md" v-model="form.year" id="year" required multiple>
                                <option value="">Select Year</option>
                                <option v-for="year in reversedYears" :key="year" :value="year">{{ year }}</option>
                            </select>

                            <InputError class="mt-2" :message="form.errors.year" />
                        </div>

                        <div class="mt-4 col-md-3">
                            <InputLabel for="name" value="Car Maker" />

                            <select class="w-full mt-1 block border-gray-300 rounded-md" v-model="form.make" id="make" required multiple>
                                <option value="">Select Make</option>
                                <option v-for="make in carMakes" :key="make" :value="make.id">{{ make.name }}</option>
                            </select>

                            <InputError class="mt-2" :message="form.errors.make" />
                        </div>

                        <div class="mt-4 col-md-3">
                            <InputLabel for="name" value="Car Model" />

                            <select class="w-full mt-1 block border-gray-300 rounded-md" v-model="form.model" id="model" required multiple>
                                <option value="">Select Model</option>
                                <option v-for="model in carModels" :key="model" :value="model.id">{{ model.name }}</option>
                            </select>

                            <InputError class="mt-2" :message="form.errors.model" />
                        </div>

                        <div class="mt-4 col-md-3">
                            <InputLabel for="name" value="Car Body Style" />

                            <TextInput
                                id="name"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="form.name"
                                required
                                autofocus
                                autocomplete="name"
                            />

                            <InputError class="mt-2" :message="form.errors.name" />
                        </div>

                    </div>

                    <div class="flex items-center justify-start my-4">
                        <PrimaryButton :class="{ 'opacity-25': form.processing }" :disabled="form.processing">
                            Add Body Style
                        </PrimaryButton>
                    </div>
                </form>
            </div>
        </div>
    </AdminAuthenticatedLayout>
</template>
